@@ -599,9 +599,10 @@ class PackageBuilder(abc.ABC):
                 pl.Path("..", "py", "scalyr_agent", "agent_main.py")
             )
 
-            agent_config_executable_path = bin_path / "scalyr-agent-2-config"
-            agent_config_executable_path.symlink_to(
-                pl.Path("..", "py", "scalyr_agent", "config_main.py")
+            # Copy the backward compatibility "scalyr-agent-2-config" script.
+            shutil.copy2(
+                constants.SOURCE_ROOT / "agent_build/linux/scalyr-agent-2-config",
+                bin_path,
             )
 
             # Write install_info file inside the "scalyr_agent" package.
@@ -1048,6 +1049,15 @@ class K8sPackageBuilder(ContainerPackageBuilder):
     RESULT_IMAGE_NAMES = ["scalyr-k8s-agent"]
 
 
+class K8sWithOpenMetricsMonitorPackageBuilder(K8sPackageBuilder):
+    """
+    An image for running the agent on Kubernetes with Kubernetes Open Metrics monitor enabled.
+    """
+
+    PACKAGE_TYPE = constants.PackageType.K8S
+    RESULT_IMAGE_NAMES = ["scalyr-k8s-agent-with-openmetrics-monitor"]
+
+
 class DockerJsonPackageBuilder(ContainerPackageBuilder):
     """
     An image for running on Docker configured to fetch logs via the file system (the container log
@@ -1132,3 +1142,18 @@ K8S_CONTAINER_BUILDER_ALPINE = K8sPackageBuilder(
     config_path=_CONFIGS_PATH / "k8s-config",
     base_image_deployment_step_cls=deployments.BuildAlpineDockerBaseImageStep,
 )
+
+K8S_CONTAINER_WITH_OPENMETRICS_MONITOR_BUILDER_DEBIAN = (
+    K8sWithOpenMetricsMonitorPackageBuilder(
+        name="k8s-with-openmetrics-monitor-debian",
+        config_path=_CONFIGS_PATH / "k8s-config-with-openmetrics-monitor",
+        base_image_deployment_step_cls=deployments.BuildDebianDockerBaseImageStep,
+    )
+)
+K8S_CONTAINER_WITH_OPENMETRICS_MONITOR_BUILDER_ALPINE = (
+    K8sWithOpenMetricsMonitorPackageBuilder(
+        name="k8s-with-openmetrics-monitor-alpine",
+        config_path=_CONFIGS_PATH / "k8s-config-with-openmetrics-monitor",
+        base_image_deployment_step_cls=deployments.BuildAlpineDockerBaseImageStep,
+    )
+)
