@@ -38,9 +38,9 @@ monitor:
       building scrapper URL.
     * ``k8s.monitor.config.scalyr.com/scrape_interval`` (optional) - How often to scrape this endpoint.
       Defaults to 60 seconds.
-    * ``k8s.monitor.config.scalyr.com/scrape_timeout`` (optional) - How long to wait before timing out.
+    * ``k8s.monitor.config.scalyr.com/scrape_timeout`` (optional) - How long to wait before timing out. This should be at least 5-10 seconds shorter than scrape interval.
     * ``k8s.monitor.config.scalyr.com/verify_https`` (optional) - Set to false to disable remote SSL
-      cert and hostname validation.
+      cert and hostname validation for this endpoint.
     * ``k8s.monitor.config.scalyr.com/attributes`` (optional) - Optional JSON object with the attributes
       (key/value pairs) which get included with every metric. Template syntax is supported for attribute
       values. Right now only pod labels are available in the template context.
@@ -85,6 +85,9 @@ for the exporter pod:
             k8s.monitor.config.scalyr.com/scrape_timeout:              '5'
             k8s.monitor.config.scalyr.com/attributes:                  '{"app": "${pod_labels_app}", "instance": "{pod_labels_app.kubernetes.io/instance}", "region": "eu"}'
             k8s.monitor.config.scalyr.com/calculate_rate_metric_names: 'docker.cpu_usage_total_seconds,docker.memory_usage_total'
+            # Or for metrics which have the same metric name, but multiple different extra field values.
+            k8s.monitor.config.scalyr.com/calculate_rate_metric_names: 'node_cpu_seconds_total:mode=user,node_cpu_seconds_total:mode=system'
+
         spec:
         containers:
         - args:
@@ -193,6 +196,8 @@ from scalyr_agent import compat
 
 __monitor__ = __name__
 
+GLOBAL_LOG = scalyr_logging.getLogger(__name__)
+
 # Default config option values
 DEFAULT_SCRAPE_INTERVAL = 60.0
 DEFAULT_SCRAPE_TIMEOUT = 10
@@ -221,6 +226,8 @@ DEFAULT_SCRAPE_SCHEME = "http"
 DEFAULT_SCRAPE_PORT = None
 DEFAULT_SCRAPE_PATH = "/metrics"
 
+CONFIG_DOCS_URL = "https://app.scalyr.com/help/scalyr-agent-k8s-explorer"
+
 define_config_option(
     __monitor__,
     "module",
@@ -269,7 +276,7 @@ define_config_option(
 define_config_option(
     __monitor__,
     "scrape_timeout",
-    "Timeout for scrape HTTP requests. Defaults to 10 seconds.",
+    "Timeout for scrape HTTP requests. Defaults to 10 seconds. This should be at least 5-10 seconds shorter than scrape interval.",
     convert_to=int,
     default=DEFAULT_SCRAPE_TIMEOUT,
 )
@@ -287,7 +294,7 @@ define_config_option(
     "scrape_kubernetes_api_cadvisor_metrics",
     "Set to True to enable scraping metrics from /metrics/cadvisor Kubernetes API endpoint.",
     convert_to=bool,
-    default=False,
+    default=True,
 )
 
 define_config_option(
@@ -378,6 +385,14 @@ define_config_option(
     default=True,
 )
 
+define_config_option(
+    __monitor__,
+    "silence_mandatory_monitors_warnings",
+    "True to silence warnings about mandatory pods not being scraped. This should be set to True when non-default / non-standard resource names are used for node-exporter DaemonSet and kube-state-metrics Deployment.",
+    convert_to=bool,
+    default=False,
+)
+
 KUBERNETES_API_METRICS_URL = Template(
     "${k8s_api_url}/api/v1/nodes/${node_name}/proxy/metrics"
 )
@@ -512,6 +527,9 @@ class KubernetesOpenMetricsMonitor(ScalyrMonitor):
         )
         self.__include_node_name = self._config.get("include_node_name", False)
         self.__include_cluster_name = self._config.get("include_cluster_name", False)
+        self.__silence_mandatory_monitors_warnings = self._config.get(
+            "silence_mandatory_monitors_warnings", False
+        )
 
         self.__k8s_api_url = self._global_config.k8s_api_url
 
@@ -539,6 +557,18 @@ class KubernetesOpenMetricsMonitor(ScalyrMonitor):
 
         self.__previous_running_monitors_count = 0
 
+        self.__enable_monitor = self._global_config.k8s_explorer_enable
+
+    def run(self):
+        if not self.__enable_monitor:
+            GLOBAL_LOG.info(
+                "kubernetes_openmetrics_monitor exiting because it's not enabled "
+                "(k8s_explorer_enable config option is not set to true)"
+            )
+            return None
+
+        return super(KubernetesOpenMetricsMonitor, self).run()
+
     @property
     def k8s(self):
         if not self._k8s:
@@ -590,6 +620,48 @@ class KubernetesOpenMetricsMonitor(ScalyrMonitor):
         self.__schedule_dynamic_open_metrics_monitors()
         self.__log_running_stats()
 
+        if self.__static_monitors_started:
+            self.__check_mandatory_monitors_are_running()
+
+    def __check_mandatory_monitors_are_running(self):
+        """
+        This method checks that the monitors which scrape node-exporter and kube-state-metrics
+        exporter pods are running.
+
+        Those two exporters are needed for the complete Kubernetes Explorer experience.
+
+        NOTE: kube-state-metrics exporter is a Deployment which only runs on a single node and
+        node-exporter is a DaemonSet.
+
+        Keep in mind that this check only covers default / standard setups and doesn't handle
+        scenario where non-standard resource names are used.
+        """
+        if self.__silence_mandatory_monitors_warnings:
+            return
+
+        has_node_exporter_monitor = False
+
+        monitor_names = self.__running_monitors.values()
+        for monitor_name in monitor_names:
+            if "node_exporter" in monitor_name or "node-exporter" in monitor_name:
+                has_node_exporter_monitor = True
+                break
+
+        if not has_node_exporter_monitor:
+            GLOBAL_LOG.warn(
+                'Could not find running OpenMetrics monitor for "node-exporter" '
+                "Deployment. Scraping node-exporter is mandatory for a complete "
+                "Kubernetes Explorer experience. For information on how to configure "
+                "scraping of node-exporter Deployment pod, please visit "
+                f"{CONFIG_DOCS_URL}",
+                limit_once_per_x_secs=(1 * 60 * 60),
+                limit_key="node_exporter_monitor_not_found",
+            )
+
+        # TODO: Also implement kube-state-metrics check - this is harder since it's a Deployment
+        # which doesn't run on every node which means we need to introduce lightweight consensus /
+        # store metadata in k8s and query it here
+
     def __log_running_stats(self):
         # We log a message either if the value from the previous run changes or every X minutes
         if self.__previous_running_monitors_count != len(self.__running_monitors):
